@@ -237,6 +237,7 @@ pub mod _detail {
         PythonObjectCallbackConverter,
     };
     pub use paste;
+    pub use std::result::Result;
 }
 
 /// Expands to an `extern "C"` function that allows Python to load
@@ -285,7 +286,7 @@ pub mod _detail {
 /// ```bash
 /// cp ./target/debug/libhello.so ./hello.so
 /// ```
-/// (Note: on Mac OS you will have to rename `libhello.dynlib` to `libhello.so`)
+/// (Note: on Mac OS you will have to rename `libhello.dynlib` to `hello.so`)
 ///
 /// The extension module can then be imported into Python:
 ///
